@@ -1,4 +1,5 @@
 use crate::cli::*;
+use crate::helper::filenames;
 
 impl ConcatCLi for ConcatParser<'_> {}
 impl InputPrint for ConcatParser<'_> {}
@@ -35,7 +36,7 @@ impl<'a> ConcatParser<'a> {
         let dir = self.parse_output(self.matches);
         let prefix = self.parse_prefix(self.matches, &dir);
         let final_path = dir.join(prefix);
-        let output = self.create_output_fname(&final_path, &output_fmt);
+        let output = filenames::create_output_fname(&final_path, &output_fmt);
         let part_fmt = self.parse_partition_fmt(self.matches);
         self.check_partition_format(&output_fmt, &part_fmt);
         let task_desc = "Alignment concatenation";
