@@ -4,7 +4,8 @@ mod convert;
 mod extract;
 mod filter;
 mod id;
-mod summary;
+mod summarize;
+mod translate;
 
 use std::ffi::OsStr;
 use std::fs;
@@ -26,11 +27,12 @@ use crate::cli::convert::ConvertParser;
 use crate::cli::extract::ExtractParser;
 use crate::cli::filter::FilterParser;
 use crate::cli::id::IdParser;
-use crate::cli::summary::SummaryParser;
+use crate::cli::summarize::SummaryParser;
+use crate::cli::translate::TranslateParser;
 
 use crate::check_output_path;
 use crate::core::msa;
-use crate::core::summary::SeqStats;
+use crate::core::summarize::SeqStats;
 use crate::helper::finder::{Files, IDs};
 use crate::helper::types::{DataType, InputFmt, OutputFmt, PartitionFmt};
 use crate::helper::utils;
@@ -48,6 +50,7 @@ pub fn parse_cli(version: &str) {
         ("id", Some(id_matches)) => IdParser::new(id_matches).get_id(),
         ("summary", Some(stats_matches)) => SummaryParser::new(stats_matches).stats(),
         ("extract", Some(extract_matches)) => ExtractParser::new(extract_matches).extract(),
+        ("translate", Some(trans_matches)) => TranslateParser::new(trans_matches).translate(),
         _ => unreachable!("Invalid subcommands!"),
     }
 }
@@ -241,14 +244,6 @@ trait OutputCli {
         }
     }
 
-    fn create_output_fname(&self, path: &Path, ext: &OutputFmt) -> PathBuf {
-        match ext {
-            OutputFmt::Fasta | OutputFmt::FastaInt => path.with_extension("fas"),
-            OutputFmt::Nexus | OutputFmt::NexusInt => path.with_extension("nex"),
-            OutputFmt::Phylip | OutputFmt::PhylipInt => path.with_extension("phy"),
-        }
-    }
-
     fn check_output_file_exist(&self, path: &Path) {
         check_output_path!(
             is_file,
