@@ -9,7 +9,7 @@ use regex::Regex;
 
 use crate::helper::sequence::{SeqCheck, Sequence};
 use crate::helper::types::{DataType, Header, InputFmt, OutputFmt, PartitionFmt, SeqMatrix};
-use crate::helper::utils;
+use crate::helper::{filenames, utils};
 use crate::writer::sequences::SeqWriter;
 
 pub enum Params {
@@ -84,11 +84,8 @@ impl<'a> Extract<'a> {
             file.file_name()
                 .expect("Failed parsing filename for output file"),
         );
-        match output_fmt {
-            OutputFmt::Fasta | OutputFmt::FastaInt => path.with_extension("fas"),
-            OutputFmt::Nexus | OutputFmt::NexusInt => path.with_extension("nex"),
-            OutputFmt::Phylip | OutputFmt::PhylipInt => path.with_extension("phy"),
-        }
+
+        filenames::create_output_fname(&path, output_fmt)
     }
 
     fn match_id(&self, id: &str, re: &str) -> bool {
