@@ -1,6 +1,7 @@
-pub mod converter;
+pub mod convert;
 pub mod extract;
 pub mod filter;
 pub mod id;
 pub mod msa;
-pub mod summary;
+pub mod summarize;
+pub mod translate;
